==> gnome-photos-3.25.4.tar.xz: gnome-photos-3.25.4/src/photos-search-match-manager.h <==
/*
 * Photos - access, organize and share your photos on GNOME
 * Copyright © 2014 – 2017 Red Hat, Inc.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301, USA.
 */

/* Based on code from:
 *   + Documents
 */

#ifndef PHOTOS_SEARCH_MATCH_MANAGER_H
#define PHOTOS_SEARCH_MATCH_MANAGER_H

#include "photos-base-manager.h"
#include "photos-search-controller.h"

G_BEGIN_DECLS

#define PHOTOS_TYPE_SEARCH_MATCH_MANAGER (photos_search_match_manager_get_type ())

#define PHOTOS_SEARCH_MATCH_MANAGER(obj) \
  (G_TYPE_CHECK_INSTANCE_CAST ((obj), \
   PHOTOS_TYPE_SEARCH_MATCH_MANAGER, PhotosSearchMatchManager))

#define PHOTOS_IS_SEARCH_MATCH_MANAGER(obj) \
  (G_TYPE_CHECK_INSTANCE_TYPE ((obj), \
   PHOTOS_TYPE_SEARCH_MATCH_MANAGER))

typedef struct _PhotosSearchMatchManager      PhotosSearchMatchManager;
typedef struct _PhotosSearchMatchManagerClass PhotosSearchMatchManagerClass;

GType                     photos_search_match_manager_get_type           (void) G_GNUC_CONST;

PhotosBaseManager        *photos_search_match_manager_new                (PhotosSearchController *srch_cntrlr);

G_END_DECLS

#endif /* PHOTOS_SEARCH_MATCH_MANAGER_H */

==> gnome-photos-3.27.4.tar.xz: gnome-photos-3.27.4/src/photos-search-match-manager.h <==
/*
 * Photos - access, organize and share your photos on GNOME
 * Copyright © 2014 – 2017 Red Hat, Inc.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301, USA.
 */

/* Based on code from:
 *   + Documents
 */

#ifndef PHOTOS_SEARCH_MATCH_MANAGER_H
#define PHOTOS_SEARCH_MATCH_MANAGER_H

#include "photos-base-manager.h"
#include "photos-search-controller.h"

G_BEGIN_DECLS

#define PHOTOS_TYPE_SEARCH_MATCH_MANAGER (photos_search_match_manager_get_type ())
G_DECLARE_FINAL_TYPE (PhotosSearchMatchManager,
                      photos_search_match_manager,
                      PHOTOS,
                      SEARCH_MATCH_MANAGER,
                      PhotosBaseManager);

PhotosBaseManager        *photos_search_match_manager_new                (PhotosSearchController *srch_cntrlr);

G_END_DECLS

#endif /* PHOTOS_SEARCH_MATCH_MANAGER_H */
